paidiverpy.models.colour_params
===============================

.. py:module:: paidiverpy.models.colour_params

.. autoapi-nested-parse::

   Colour layer parameters models.

   ..
       !! processed by numpydoc !!


Classes
-------

.. autoapisummary::

   paidiverpy.models.colour_params.GrayScaleParams
   paidiverpy.models.colour_params.GaussianBlurParams
   paidiverpy.models.colour_params.SharpenParams
   paidiverpy.models.colour_params.ContrastAdjustmentParams
   paidiverpy.models.colour_params.IlluminationCorrectionParams
   paidiverpy.models.colour_params.DeblurParams
   paidiverpy.models.colour_params.ColourAlterationParams
   paidiverpy.models.colour_params.EdgeDetectionParams


Module Contents
---------------

.. py:class:: GrayScaleParams(/, **data: Any)

   Bases: :py:obj:`paidiverpy.utils.base_model.BaseModel`


   
   Parameters for the grayscale conversion.
















   ..
       !! processed by numpydoc !!

.. py:class:: GaussianBlurParams(/, **data: Any)

   Bases: :py:obj:`paidiverpy.utils.base_model.BaseModel`


   
   Parameters for Gaussian blur.
















   ..
       !! processed by numpydoc !!

.. py:class:: SharpenParams(/, **data: Any)

   Bases: :py:obj:`paidiverpy.utils.base_model.BaseModel`


   
   Parameters for sharpening.
















   ..
       !! processed by numpydoc !!

.. py:class:: ContrastAdjustmentParams(/, **data: Any)

   Bases: :py:obj:`paidiverpy.utils.base_model.BaseModel`


   
   Parameters for contrast adjustment.
















   ..
       !! processed by numpydoc !!

.. py:class:: IlluminationCorrectionParams(/, **data: Any)

   Bases: :py:obj:`paidiverpy.utils.base_model.BaseModel`


   
   Parameters for illumination correction.
















   ..
       !! processed by numpydoc !!

.. py:class:: DeblurParams(/, **data: Any)

   Bases: :py:obj:`paidiverpy.utils.base_model.BaseModel`


   
   Parameters for deblurring.
















   ..
       !! processed by numpydoc !!

.. py:class:: ColourAlterationParams(/, **data: Any)

   Bases: :py:obj:`paidiverpy.utils.base_model.BaseModel`


   
   Parameters for colour alteration.
















   ..
       !! processed by numpydoc !!

.. py:class:: EdgeDetectionParams(/, **data: Any)

   Bases: :py:obj:`paidiverpy.utils.base_model.BaseModel`


   
   Parameters for edge detection.
















   ..
       !! processed by numpydoc !!

